@@ -2,16 +2,47 @@
 #'
 #' This pair of functions makes it easy to create paired R and test files,
 #' using the convention that the tests for `R/foofy.R` should live
-#' in `tests/testhat/test-foofy.R`. You can use them to create new files
+#' in `tests/testthat/test-foofy.R`. You can use them to create new files
 #' from scratch by supplying `name`, or if you use RStudio, you can call
 #' to create (or navigate to) the paired file based on the currently open
 #' script.
 #'
+#' @section Renaming files in an existing package:
+#'
+#' Here are some tips on aligning file names across `R/` and `tests/testthat/`
+#' in an existing package that did not necessarily follow this convention
+#' before.
+#'
+#' This script generates a data frame of `R/` and test files that can help you
+#' identify missed opportunities for pairing:
+#'
+#' ```
+#' library(fs)
+#' library(tidyverse)
+#'
+#' bind_rows(
+#'   tibble(
+#'     type = "R",
+#'     path = dir_ls("R/", regexp = "\\.[Rr]$"),
+#'     name = as.character(path_ext_remove(path_file(path))),
+#'   ),
+#'   tibble(
+#'     type = "test",
+#'     path = dir_ls("tests/testthat/", regexp = "/test[^/]+\\.[Rr]$"),
+#'     name = as.character(path_ext_remove(str_remove(path_file(path), "^test[-_]"))),
+#'   )
+#' ) %>%
+#'   pivot_wider(names_from = type, values_from = path) %>%
+#'   print(n = Inf)
+#' ```
+#'
+#' The [rename_files()] function can also be helpful.
+#'
 #' @param name Either a name without extension, or `NULL` to create the
 #'   paired file based on currently open file in the script editor. If
-#'   the R file is open, `use_test()` will create/open the corresponding
+#'   the `R/` file is open, `use_test()` will create/open the corresponding
 #'   test file; if the test file is open, `use_r()` will create/open the
-#'   corresponding R file.
+#'   corresponding `R/` file.
 #' @inheritParams edit_file
 #' @seealso The [testing](https://r-pkgs.org/tests.html) and
 #'   [R code](https://r-pkgs.org/r.html) chapters of
@@ -38,7 +69,7 @@ use_r <- function(name = NULL, open = rlang::is_interactive()) {
 #' @export
 use_test <- function(name = NULL, open = rlang::is_interactive()) {
   if (!uses_testthat()) {
-    use_testthat()
+    use_testthat_impl()
   }
 
   name <- name %||% get_active_r_file(path = "R")
@@ -84,20 +115,33 @@ rename_files <- function(old, new) {
   }
 
   if (!uses_testthat()) {
-    return()
+    return(invisible())
   }
 
-  # Move test files
+  # Move test files and snapshots
   rename_test <- function(path) {
     file <- gsub(glue("^test-{old}"), glue("test-{new}"), path_file(path))
+    file <- gsub(glue("^{old}.md"), glue("{new}.md"), file)
     path(path_dir(path), file)
   }
-  old_test <- dir_ls(proj_path("tests", "testthat"), glob = glue("*/test-{old}*"))
+  old_test <- dir_ls(
+    proj_path("tests", "testthat"),
+    glob = glue("*/test-{old}*")
+  )
   new_test <- rename_test(old_test)
   if (length(old_test) > 0) {
     ui_done("Moving {ui_path(old_test)} to {ui_path(new_test)}")
     file_move(old_test, new_test)
   }
+  snaps_dir <- proj_path("tests", "testthat", "_snaps")
+  if (dir_exists(snaps_dir)) {
+    old_snaps <- dir_ls(snaps_dir, glob = glue("*/{old}.md"))
+    if (length(old_snaps) > 0) {
+      new_snaps <- rename_test(old_snaps)
+      ui_done("Moving {ui_path(old_snaps)} to {ui_path(new_snaps)}")
+      file_move(old_snaps, new_snaps)
+    }
+  }
 
   # Update test file
   test_path <- proj_path("tests", "testthat", glue("test-{new}"), ext = "R")
@@ -151,7 +195,7 @@ valid_file_name <- function(x) {
 }
 
 get_active_r_file <- function(path = "R") {
-  if (!rstudioapi::isAvailable()) {
+  if (!rstudio_available()) {
     ui_stop("Argument {ui_code('name')} must be specified.")
   }
   active_file <- rstudioapi::getSourceEditorContext()$path
